==> packageinstaller-pkglist_0.3.29.tar.xz: packageinstaller-pkglist/Serbian_firefox.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Serbian_Firefox
</name>

<description>
   <am>Serbian localisation of Firefox</am>
   <ar>Serbian localisation of Firefox</ar>
   <be>Serbian localisation of Firefox</be>
   <bg>Serbian localisation of Firefox</bg>
   <bn>Serbian localisation of Firefox</bn>
   <ca>Localització de Firefox en Serbi</ca>
   <cs>Serbian localisation of Firefox</cs>
   <da>Serbisk oversættelse af Firefox</da>
   <de>Serbische Lokalisierung von Firefox</de>
   <el>Σερβικά για το Firefox</el>
   <en>Serbian localisation of Firefox</en>
   <es_ES>Localización Serbia de Firefox</es_ES>
   <es>Localización Serbio de Firefox</es>
   <et>Serbian localisation of Firefox</et>
   <eu>Serbian localisation of Firefox</eu>
   <fa>Serbian localisation of Firefox</fa>
   <fil_PH>Serbian localisation of Firefox</fil_PH>
   <fi>Serbialainen Firefox-kotoistus</fi>
   <fr_BE>Serbian localisation of Firefox</fr_BE>
   <fr>Localisation en serbe pour Firefox</fr>
   <gl_ES>Localización de Firefox ao serbio</gl_ES>
   <he_IL>Serbian localisation of Firefox</he_IL>
   <hi>Serbian localisation of Firefox</hi>
   <hr>Serbian localisation of Firefox</hr>
   <hu>Serbian localisation of Firefox</hu>
   <id>Serbian localisation of Firefox</id>
   <is>Serbian localisation of Firefox</is>
   <it>Localizzazione serba di Firefox</it>
   <ja>Firefox のセルビア語版</ja>
   <kk>Serbian localisation of Firefox</kk>
   <ko>Serbian localisation of Firefox</ko>
   <lt>Serbian localisation of Firefox</lt>
   <mk>Serbian localisation of Firefox</mk>
   <mr>Serbian localisation of Firefox</mr>
   <nb_NO>Serbian localisation of Firefox</nb_NO>
   <nb>Serbisk lokaltilpassing av Firefox</nb>
   <nl_BE>Serbian localisation of Firefox</nl_BE>
   <nl>Servische lokalisatie van Firefox</nl>
   <pl>Serbska lokalizacja przeglądarki Firefox</pl>
   <pt_BR>Sérvio Localização para o Firefox</pt_BR>
   <pt>Sérvio Localização para Firefox</pt>
   <ro>Serbian localisation of Firefox</ro>
   <ru>Сербская локализация Firefox</ru>
   <sk>Serbian localisation of Firefox</sk>
   <sl>Serbian localisation of Firefox</sl>
   <sq>Serbian localisation of Firefox</sq>
   <sr>Serbian localisation of Firefox</sr>
   <sv>Serbisk  lokalisering av Firefox</sv>
   <th>Serbian localisation ของ Firefox</th>
   <tr>Firefox'un Sırpça yerelleştirmesi</tr>
   <uk>Serbian localisation of Firefox</uk>
   <vi>Serbian localisation of Firefox</vi>
   <zh_CN>Serbian localisation of Firefox</zh_CN>
   <zh_HK>Serbian localisation of Firefox</zh_HK>
   <zh_TW>Serbian localisation of Firefox</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
firefox-l10n-xpi-sr
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
firefox-l10n-xpi-sr
</uninstall_package_names>
</app>

==> packageinstaller-pkglist_0.3.32.tar.xz: packageinstaller-pkglist/Serbian_firefox.pm <==
<?xml version="1.0"?>
<app>

<category>
Language
</category>

<name>
Serbian_Firefox
</name>

<description>
   <am>Serbian localisation of Firefox</am>
   <ar>Serbian localisation of Firefox</ar>
   <be>Serbian localisation of Firefox</be>
   <bg>Serbian localisation of Firefox</bg>
   <bn>Serbian localisation of Firefox</bn>
   <ca>Localització de Firefox en Serbi</ca>
   <cs>Serbian localisation of Firefox</cs>
   <da>Serbisk oversættelse af Firefox</da>
   <de>Serbische Lokalisierung von Firefox</de>
   <el>Σερβικά για το Firefox</el>
   <en>Serbian localisation of Firefox</en>
   <es_ES>Localización Serbia de Firefox</es_ES>
   <es>Localización Serbio de Firefox</es>
   <et>Serbian localisation of Firefox</et>
   <eu>Serbian localisation of Firefox</eu>
   <fa>Serbian localisation of Firefox</fa>
   <fil_PH>Serbian localisation of Firefox</fil_PH>
   <fi>Serbialainen Firefox-kotoistus</fi>
   <fr_BE>Serbian localisation of Firefox</fr_BE>
   <fr>Localisation en serbe pour Firefox</fr>
   <gl_ES>Localización de Firefox ao serbio</gl_ES>
   <gu>Serbian localisation of Firefox</gu>
   <he_IL>Serbian localisation of Firefox</he_IL>
   <hi>फायरफॉक्स का सर्बियाई संस्करण</hi>
   <hr>Serbian localisation of Firefox</hr>
   <hu>Serbian localisation of Firefox</hu>
   <id>Serbian localisation of Firefox</id>
   <is>Serbian localisation of Firefox</is>
   <it>Localizzazione serba di Firefox</it>
   <ja>Firefox のセルビア語版</ja>
   <kk>Serbian localisation of Firefox</kk>
   <ko>Serbian localisation of Firefox</ko>
   <lt>Serbian localisation of Firefox</lt>
   <mk>Serbian localisation of Firefox</mk>
   <mr>Serbian localisation of Firefox</mr>
   <nb_NO>Serbian localisation of Firefox</nb_NO>
   <nb>Serbisk lokaltilpassing av Firefox</nb>
   <nl_BE>Serbian localisation of Firefox</nl_BE>
   <nl>Servische lokalisatie van Firefox</nl>
   <pl>Serbska lokalizacja przeglądarki Firefox</pl>
   <pt_BR>Sérvio Localização para o Firefox</pt_BR>
   <pt>Sérvio Localização para Firefox</pt>
   <ro>Serbian localisation of Firefox</ro>
   <ru>Сербская локализация Firefox</ru>
   <sk>Serbian localisation of Firefox</sk>
   <sl>Serbian localisation of Firefox</sl>
   <sq>Serbian localisation of Firefox</sq>
   <sr>Serbian localisation of Firefox</sr>
   <sv>Serbisk  lokalisering av Firefox</sv>
   <th>Serbian localisation ของ Firefox</th>
   <tr>Firefox'un Sırpça yerelleştirmesi</tr>
   <uk>Serbian localisation of Firefox</uk>
   <vi>Serbian localisation of Firefox</vi>
   <zh_CN>Serbian localisation of Firefox</zh_CN>
   <zh_HK>Serbian localisation of Firefox</zh_HK>
   <zh_TW>Serbian localisation of Firefox</zh_TW>
</description>

<installable>
all
</installable>

<screenshot>none</screenshot>

<preinstall>

</preinstall>

<install_package_names>
firefox-l10n-xpi-sr
</install_package_names>


<postinstall>

</postinstall>


<uninstall_package_names>
firefox-l10n-xpi-sr
</uninstall_package_names>
</app>
